{ config
, pkgs
, inputs
, ...
}:
let
  wallpaper = inputs.nix-wallpaper.packages.${pkgs.system}.default.override {
    logoSize = 24;
    preset = "gruvbox-dark-rainbow";
  };
  wallpaperPath = "${wallpaper}/share/wallpapers/nixos-wallpaper.png";
in
{
  programs.mpv = {
    enable = true;
    package = pkgs.mpv;
  };
  programs.thunderbird = {
    enable = true;
    package = pkgs.betterbird;
    profiles."main" = {
      isDefault = true;
    };
  };
  programs.nheko = {
    enable = true;
  };
  programs.obs-studio = {
    enable = true;
    plugins = with pkgs.obs-studio-plugins; [
      wlrobs
      obs-backgroundremoval
      obs-pipewire-audio-capture
      obs-vaapi
      obs-gstreamer
    ];
  };

  home = {
    file.".background.png".source = wallpaperPath;

    packages = with pkgs; [
      bitwarden
      airshipper
      ardour
      # blender
      brave
      cavalier
      ffmpeg
      freetube
      filelight
      element-desktop
      inkscape
      jellyfin-mpv-shim
      pkgs.unstable-pkgs.warp-terminal
      libsForQt5.kasts
      # miraclecast
      krita
      kdePackages.kate
      kdePackages.kdenlive
      kdePackages.kleopatra
      kdePackages.plasma-vault
      kdePackages.plasma-browser-integration
      kdePackages.kio-admin
      nextcloud-client
      onlyoffice-bin
      protonup-qt
      # rustdesk
      signal-desktop
      webcord-vencord
      tome4
      shattered-pixel-dungeon
      gst_all_1.gst-vaapi
      ace-of-penguins
      waypipe
      veracrypt
    ];
  };
}
